@@ -6,7 +6,7 @@ hr_kde <- function(x, ...) {
 
 #' @export
 #' @rdname hr
-hr_kde.track_xy <- function(x, h = hr_kde_ref(x), trast = raster(as_sp(x), nrow = 100, ncol = 100), ...) {
+hr_kde.track_xy <- function(x, h = hr_kde_ref(x), trast = make_trast(x), ...) {
 
   # ---------------------------------------------------------------------------- #
   # Check bandwidth
@@ -43,7 +43,7 @@ hr_kde.track_xy <- function(x, h = hr_kde_ref(x), trast = raster(as_sp(x), nrow
     h = h,
     ud = kde
   )
-  class(res) <- c("kde", "hr", class(res))
+  class(res) <- c("kde", "hr_prob", "hr", class(res))
   res
 }
 
